# arXiv Filter

## Usage
Run with

    python3 -m arxiv_filter

Then drag and drop the text of an arXiv daily e-mail blast anywhere into the window.

## Dependencies
- Python 3
  - pyyaml
- Qt5
- PyQt5
